"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBlockPublicKeySet = exports.getDataFromDBStream = void 0;
const lisk_codec_1 = require("@liskhq/lisk-codec");
const constants_1 = require("../constants");
const schemas_1 = require("../schemas");
const transaction_1 = require("./transaction");
const getDataFromDBStream = async (stream, schema) => {
    const data = await new Promise((resolve, reject) => {
        const result = [];
        stream
            .on('data', async ({ value }) => {
            const decodedResult = await lisk_codec_1.codec.decode(schema, value);
            result.push(decodedResult);
        })
            .on('error', error => {
            reject(error);
        })
            .on('end', () => {
            resolve(result);
        });
    });
    return data;
};
exports.getDataFromDBStream = getDataFromDBStream;
const getBlockPublicKeySet = async (db, pageSize) => {
    const result = new Set();
    let startingKey = Buffer.from(`${constants_1.DB_KEY_BLOCKS_ID}:${(0, transaction_1.keyString)(Buffer.alloc(32, 0))}`);
    while (true) {
        let exist = false;
        const blocksStream = db.createReadStream({
            gte: startingKey,
            lte: Buffer.from(`${constants_1.DB_KEY_BLOCKS_ID}:${(0, transaction_1.keyString)(Buffer.alloc(32, 255))}`),
            limit: pageSize,
        });
        let lastKey = startingKey;
        await new Promise((resolve, reject) => {
            blocksStream
                .on('data', async ({ key, value }) => {
                exist = true;
                const header = await lisk_codec_1.codec.decode(schemas_1.blockHeaderSchema, value);
                result.add(header.generatorPublicKey.toString('hex'));
                lastKey = key;
            })
                .on('error', error => {
                reject(error);
            })
                .on('end', () => {
                resolve();
            });
        });
        if (!exist) {
            break;
        }
        startingKey = (0, transaction_1.incrementOne)(lastKey);
    }
    return result;
};
exports.getBlockPublicKeySet = getBlockPublicKeySet;
//# sourceMappingURL=block.js.map